// Load the data from graph.json
d3.json('graph.json')
  .then(function (data) {
    const links = data.links;
    const nodes = data.nodes;

    // Create SVG element
    const svg = d3.select('svg'),
      width = +svg.attr('width'),
      height = +svg.attr('height');

    // Create simulation
    const simulation = d3
      .forceSimulation(nodes)
      .force(
        'link',
        d3
          .forceLink(links)
          .id((d) => d.id)
          .distance(150),
      )
      .force('charge', d3.forceManyBody().strength(-200))
      .force(
        'center',
        d3.forceCenter(width / 2, height / 2),
      );

    // Draw links
    const link = svg
      .selectAll('.link')
      .data(links)
      .enter()
      .append('line')
      .attr('class', 'link');

    // Draw nodes
    const node = svg
      .selectAll('.node')
      .data(nodes)
      .enter()
      .append('g')
      .attr('class', 'node')
      .call(
        d3
          .drag()
          .on('start', dragstarted)
          .on('drag', dragged)
          .on('end', dragended),
      );

    node
      .append('circle')
      .attr('r', 8)
      .attr('fill', (d) => color(d.group));

    node
      .append('text')
      .text((d) => d.id)
      .attr('x', 12)
      .attr('y', '.31em');

    simulation.on('tick', () => {
      link
        .attr('x1', (d) => d.source.x)
        .attr('y1', (d) => d.source.y)
        .attr('x2', (d) => d.target.x)
        .attr('y2', (d) => d.target.y);

      node.attr(
        'transform',
        (d) => `translate(${d.x},${d.y})`,
      );
    });

    function dragstarted(event, d) {
      if (!event.active)
        simulation.alphaTarget(0.3).restart();
      d.fx = d.x;
      d.fy = d.y;
    }

    function dragged(event, d) {
      d.fx = event.x;
      d.fy = event.y;
    }

    function dragended(event, d) {
      if (!event.active) simulation.alphaTarget(0);
      d.fx = null;
      d.fy = null;
    }
  })
  .catch(function (error) {
    console.error('Error loading the data: ' + error);
  });

// Define color scale for nodes
const color = d3.scaleOrdinal(d3.schemeCategory10);
